==> nextcloud-30.0.5.tgz: nextcloud/apps/oauth2/l10n/br.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "N'eo ket aotreet ho kliant d'en em kenstagañ. Galvit merour ho kliant.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Ho adhenter URL en deus ezhomm bezhañ un URL klog da skouer : https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Oatreit an dilesa a glot gant OAuth 2.0 diouzh ho meziant web.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Aotreant a raio ar meziant OAuth 2.0 ar merour da arventennoù evit an dilesa red-labour e-barzh evit aotreañ an dilesa a glot gant OAuth 2.0 eus meziantoù web all.",
    "OAuth 2.0 clients" : "Kliant OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "Aotreañ a ra OAuth 2.0 ar servijourienn diavaez da goulenn tizhout {instanceName}.",
    "Name" : "Anv",
    "Redirection URI" : "Adhent URL",
    "Client Identifier" : "Anavezer Kliant",
    "Secret key" : "Alc'hwez sekred",
    "Add client" : "Ouzhoennañ kliant",
    "Add" : "Ouzhpennañ",
    "Delete" : "Dilemel",
    "Show client secret" : "Diskouez sekret ar kliant"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");

==> nextcloud-31.0.12.tgz: nextcloud/apps/oauth2/l10n/br.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "N'eo ket aotreet ho kliant d'en em kenstagañ. Galvit merour ho kliant.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Ho adhenter URL en deus ezhomm bezhañ un URL klog da skouer : https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Oatreit an dilesa a glot gant OAuth 2.0 diouzh ho meziant web.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Aotreant a raio ar meziant OAuth 2.0 ar merour da arventennoù evit an dilesa red-labour e-barzh evit aotreañ an dilesa a glot gant OAuth 2.0 eus meziantoù web all.",
    "OAuth 2.0 clients" : "Kliant OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "Aotreañ a ra OAuth 2.0 ar servijourienn diavaez da goulenn tizhout {instanceName}.",
    "Name" : "Anv",
    "Redirection URI" : "Adhent URL",
    "Client Identifier" : "Anavezer Kliant",
    "Secret key" : "Alc'hwez sekred",
    "Add client" : "Ouzhoennañ kliant",
    "Add" : "Ouzhpennañ",
    "Show client secret" : "Diskouez sekret ar kliant",
    "Delete" : "Dilemel"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
